%{
@Name:ao_dc_voltage.m
@Author: Smacq
@Copyright: Smacq
@Date: 12-17-2024
@Brief:
The Ao functions of USB-3000, angle output fixed voltage.
Set device A0~3 output 4.5V and 0V.
Set AO output 1V, A1 output 2V, A2 output 3V, A3 output 4V.
Analog voltage range is -10V ~ +10V.
Ao channel is different for modul, Ao_4 or NONE.
You can look at user manual know more about functions or Device info.

USB-3000 only connect USB execution result (Matlab version, similar concept as Python example):
MATLAB is 64-bit.
Dll load success.
0
"0" "All AOchannel is 4.5V."
"0" "All AOchannel is 0V."
"0" "All AOchannel is 4.5V."
"0" "All AOchannel is 0V."
"0" "All AOchannel is 4.5V."
"0" "All AOchannel is 0V."
"0" "All AOchannel is 4.5V."
"0" "All AOchannel is 0V."
"0" "All AOchannel is 4.5V."
"0" "All AOchannel is 0V."
"0" "AOchannel 0 is 1V."
"0" "AOchannel 1 is 2V."
"0" "AOchannel 2 is 3V."
"0" "AOchannel 3 is 4V."
0 
%}

% Clear workspace and command window
clear;
clc;

% Check MATLAB bit is 32 or 64, load different lib file
if exist('matlab\private\util', 'dir') ~= 7
    dll_file_path = '.\lib\x64\USB3000.dll';  % If MATLAB is 64-bit, use this DLL path
    fprintf('MATLAB is 64-bit.\n');
else
    dll_file_path = '.\lib\x86\USB3000.dll';  % If MATLAB is 32-bit, use this DLL path
    fprintf('MATLAB is 32-bit.\n');
end

h_file_path = '.\lib\USB3000.h';

try
    loadlibrary(dll_file_path, h_file_path);
    if libisloaded('USB3000')
        fprintf('Dll load success.\n');
    end
catch
    fprintf('Dll load Fail please check matlab bit and lib file path.\n');
end

% Device index starts from zero
DeviceIndex = int32(0);

% Ao channel, Ao channel 0 to Ao channel 3
AOChannel_0 = uint8(0);
AOChannel_1 = uint8(1);
AOChannel_2 = uint8(2);
AOChannel_3 = uint8(3);

% voltage value, range is -10 to +10
voltage_4_5 = single(4.5);
voltage_4 = single(4);
voltage_3 = single(3);
voltage_2 = single(2);
voltage_1 = single(1);
voltage_0 = single(0);

% Open specific device and print return value.
ErrorCode = calllib('USB3000', 'USB3OpenDevice', DeviceIndex);
disp(ErrorCode);

% Set all Ao channel 0V or 5V Interval of 1 second
for i = 1:5
    ErrorCode = calllib('USB3000', 'SetUSB3AoImmediately4Chans', DeviceIndex, voltage_4_5, voltage_4_5, voltage_4_5, voltage_4_5);
    disp([ErrorCode, " All AOChannel is 4.5V"]);
    pause(1);
    ErrorCode = calllib('USB3000', 'SetUSB3AoImmediately4Chans', DeviceIndex, voltage_0, voltage_0, voltage_0, voltage_0);
    disp([ErrorCode, " All AOChannel is 0V"]);
    pause(1);
end

% Set single Ao channel
ErrorCode = calllib('USB3000', 'SetUSB3AoImmediately', DeviceIndex, AOChannel_0, voltage_1);
disp([ErrorCode, " AOChannel_0 is 1V"]);
ErrorCode = calllib('USB3000', 'SetUSB3AoImmediately', DeviceIndex, AOChannel_1, voltage_2);
disp([ErrorCode, " AOChannel_1 is 2V"]);
ErrorCode = calllib('USB3000', 'SetUSB3AoImmediately', DeviceIndex, AOChannel_2, voltage_3);
disp([ErrorCode, " AOChannel_2 is 3V"]);
ErrorCode = calllib('USB3000', 'SetUSB3AoImmediately', DeviceIndex, AOChannel_3, voltage_4);
disp([ErrorCode, " AOChannel_3 is 4V"]);

% Close Device
ErrorCode = calllib('USB3000', 'USB3CloseDevice', DeviceIndex);
disp(ErrorCode);

% Unload the dynamic link library
unloadlibrary('USB3000');