%{
@Name:do_immediately.m
@Author: Smacq
@Copyright: Smacq
@Date: 2024/12/19
@Brief:
The Do functions of USB-3000, digit output.
Set Do output HIGH/LOW, 0 0V is LOW(default), 3.3V HIGH.
DO channel is different for modul, Do_4 or Do_8.
You can look at user manual know more about functions or Device info.

USB-3000(DO_4) only connect USB execution result:
MATLAB is 64-bit.
Dll load success.
     0
     0
Now Do3-0 is all HIGH
     0
Now Do3-0 is all LOW
     0
Now Do3-0 is all HIGH
     0
Now Do3-0 is all LOW
     0
Now Do3-0 is all HIGH
     0
Now Do3-0 is all LOW
     0
Now DO 0 is 1
     0
Now DO 0 is 0
     0
Now DO 0 is 1
     0
Now DO 0 is 0
     0
Now DO 0 is 1
     0
Now DO 0 is 0
     0
%}

% Clear workspace and command window
clear;
clc;

% Check MATLAB bit is 32 or 64, load different lib file
if exist('matlab\private\util', 'dir') ~= 7
    dll_file_path = '.\lib\x64\USB3000.dll';  % If MATLAB is 64-bit, use this DLL path
    fprintf('MATLAB is 64-bit.\n');
else
    dll_file_path = '.\lib\x86\USB3000.dll';  % If MATLAB is 32-bit, use this DLL path
    fprintf('MATLAB is 32-bit.\n');
end

h_file_path = '.\lib\USB3000.h';

try
    loadlibrary(dll_file_path, h_file_path);
    if libisloaded('USB3000')
        fprintf('Dll load success.\n');
    end
catch
    fprintf('Dll load Fail please check matlab bit and lib file path.\n');
end

% Device index starts from zero
DeviceIndex = int32(0);

% For all select digital output channel:
% 0xFF is select all digital output channel.
All_Do_Channel = uint32(0xFF);

% For all Do output Do_Value HIGH is 1 or LOW is 0:
% Do_channel_4:0~0xF(1111) Do3~Do0, Do_channel_8:0~0xFF(1111 1111) Do7~Do0.
All_Do_Value = uint32(0xF);

% For select single digital output channel:
% Do_channel_4:0~3 -> Do3~Do0, Do_channel_8:0~7 -> Do7~Do0.
single_Do_Channel = uint32(0);

% single Do output Do_Value HIGH is 1:
single_Do_Value_HIGH = uint32(1);

% single Do output Do_Value LOW is 0:
single_Do_Value_LOW = uint32(0);

% Open specific device and print return value.
ErrorCode = calllib('USB3000', 'USB3OpenDevice', DeviceIndex);
disp(ErrorCode);

% Set All Do Pin output HIGH and then LOW, interval of 1 second.
for i = 1:3
    % Set Do Pin output, 15=0xF=4-bit(1111) Do3-0 all HIGH.
    ErrorCode = calllib('USB3000', 'SetUSB3DoImmediately', DeviceIndex, All_Do_Channel, All_Do_Value);
    disp(ErrorCode);
    if ErrorCode == 0
        fprintf('Now Do3-0 is all HIGH\n');
    end
    % Necessary delay for easy observation
    pause(1);
    % Set Do Pin output, 0=0x0=4-bit(0000) Do3-0 all LOW.
    ErrorCode = calllib('USB3000', 'SetUSB3DoImmediately', DeviceIndex, All_Do_Channel, 0);
    disp(ErrorCode);
    if ErrorCode == 0
        fprintf('Now Do3-0 is all LOW\n');
    end
    % Necessary delay for easy observation
    pause(1);
end

% Set single DO_0 output HIGH/LOW, interval of 1 second.
for i = 1:3
    ErrorCode = calllib('USB3000', 'SetUSB3DoImmediately', DeviceIndex, single_Do_Channel, single_Do_Value_HIGH);
    disp(ErrorCode);
    if ErrorCode == 0
        fprintf('Now DO %d is %d\n', single_Do_Channel, single_Do_Value_HIGH);
    end
    pause(1);
    ErrorCode = calllib('USB3000', 'SetUSB3DoImmediately', DeviceIndex, single_Do_Channel, single_Do_Value_LOW);
    disp(ErrorCode);
    if ErrorCode == 0
        fprintf('Now DO %d is %d\n', single_Do_Channel, single_Do_Value_LOW);
    end
    pause(1);
end

% Close Device
ErrorCode = calllib('USB3000', 'USB3CloseDevice', DeviceIndex);
disp(ErrorCode);

% Unload the dynamic link library
unloadlibrary('USB3000');